@@ -39,7 +39,7 @@ class Client:
         #get settings from api endpoint
         config_api = {}
         if self.api_key and self.api_endpoint:
-            response = requests.get(url = self.api_endpoint + "/get", params = {"q":self.api_key})
+            response = requests.get(url = self.api_endpoint + "/" + self.api_key)
             if response.status_code == 200:
                 config_api = response.json();
         #initialize confing
@@ -127,7 +127,7 @@ class Client:
         self.chromedriver_path = config.get("chromedriver_path", "/usr/lib/chromium-browser/chromedriver")
        
         #max likes
-        self.likes_max = config_api.get("likes", config.get("likes", 15)).split("-")
+        self.likes_max = config_api.get("likes", config.get("likes", 15)).split(",")
         
         if len(self.likes_max) == 2:
             self.likes_max = randint(int(self.likes_max[0].strip()),int(self.likes_max[1].strip()))
@@ -137,14 +137,14 @@ class Client:
         self.watch_stories_minutes = int(config_api.get("watch_stories",config.get("watch_stories", 5)))
         
         #follows max
-        self.follows_max = config_api.get("follows", config.get("follows", 0)).split("-")
+        self.follows_max = config_api.get("follows", config.get("follows", 0)).split(",")
         if len(self.follows_max) == 2:
             self.follows_max = randint(int(self.follows_max[0].strip()),int(self.follows_max[1].strip()))
         else:
             self.follows_max = int(self.follows_max[0].strip())
 
         #unfollows max
-        self.unfollows_max = config_api.get("unfollows", config.get("unfollows", 0)).split("-")
+        self.unfollows_max = config_api.get("unfollows", config.get("unfollows", 0)).split(",")
         if len(self.unfollows_max) == 2:
             self.unfollows_max = randint(int(self.unfollows_max[0].strip()),int(self.unfollows_max[1].strip()))
         else:
@@ -233,7 +233,6 @@ class Client:
                         if  lastRun == "":
                             lastRun = lastRun_arr[0].strip()
                             #bot was stuck - reset the bot trigger
-                            print(lastRun)
                             if is_date(lastRun)  and self.wait_between > 0 and self.hours_between(str(self.start),lastRun) > self.wait_between:
                                 with open(self.path  + self.user + ".log", "a") as f:
                                     f.write("\n")
@@ -241,7 +240,7 @@ class Client:
                             else:
                                 return False
                         #logged more information than needed - reset the bot trigger
-                        elif isinstance(lastRun.strip(), numbers.Number) or len(lastRun_arr) != 6:
+                        elif isinstance(lastRun, numbers.Number) or len(lastRun_arr) != 8:
                             with open(self.path  + self.user + ".log", "a") as f:
                                 f.write("\n")
                             return False
@@ -639,8 +638,8 @@ class Client:
     def send_data(self):
         if not self.api_key or not self.api_endpoint:
             return
-        PARAMS = {"q":self.api_key, "data": self.start +"," + self.end + "," + str(self.followers_count) + "," + str(self.following_count) + "," +  str(self.likes) + "," + str(self.home_screen_likes) + "," + str(self.follows + self.follow_recent_liked) + "," + str(self.unfollows) + "," + str(self.stories_watched)}
-        r = requests.get(url = self.api_endpoint + "/write",params = PARAMS)
+        DATA = {"log_time_start": self.start, "log_time_end":  self.end, "followers": str(self.followers_count),"following": str(self.following_count), "likes": str(self.likes), "likes_home": str(self.home_screen_likes), "follows": str(self.follows + self.follow_recent_liked), "unfollows": str(self.unfollows), "stories_watched": str(self.stories_watched)}
+        r = requests.post(url = self.api_endpoint + "/write/" + self.api_key, data = DATA)
 
     def run (self):
         try:
